# Contributing

When contributing to this repository, please first discuss the change you wish to make via issue,
email, or any other method with the maintainers of this repository, in particular [Hearot](https://github.com/hearot), before making a change.

Please note we have a [code of conduct](./CODE_OF_CONDUCT.md); you **must** follow it in all your interactions with the project.

## Pull Request Process

1. Ensure you installed all the development requirements and make sure you tested all the examples and the tests with `pytest`.
2. Commit following [Conventional Commits](https://www.conventionalcommits.org).
3. You may merge the Pull Request in once you have the approval of all the maintainers.
